#include <SDL.h>
#include <math.h>
#include <string.h>
#include "gfx.h"

/* Video main buffer */
static SDL_Surface *surface = NULL;

/* ************************************************************************* */
int init_gfx (int resx, int resy, int bpp, int fullscreen)
{
  /* Initialize SDL library */
  SDL_Init( SDL_INIT_VIDEO );
  atexit( SDL_Quit );

  /* Set video mode */
  surface = SDL_SetVideoMode( resx, resy, bpp, 
			      fullscreen ? 
			      SDL_HWSURFACE | SDL_FULLSCREEN : SDL_SWSURFACE );
  /* Check if succeed */
  if ( !surface ) return 0;

  /* Hide mouse cursor in fullscreen mode */
  if ( fullscreen ) SDL_ShowCursor( 0 );

  return 1;
}

/* ************************************************************************* */
int update_display (void)
{
  return SDL_Flip(surface);
}

int save_display (char *file_name)
{
   if (surface != NULL) return SDL_SaveBMP (surface,file_name);
   return -1;
}

/*
/* ************************************************************************* */
int rectangle (int x, int y, unsigned w, unsigned h, unsigned color)
{
  unsigned c = 
    SDL_MapRGB( surface->format, 
		( color >> 16 ) & 0xFF, ( color >> 8  ) & 0xFF,  color & 0xFF);
  SDL_Rect rect = { x, y, w, h };
  return !SDL_FillRect( surface, &rect, c );
}

/* ************************************************************************* */
void done_gfx (void)
{
  SDL_FreeSurface (surface);
}

